"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const Utils_1 = require("../Utils/Utils");
class Create extends command_1.Command {
    async run() {
        const { args } = this.parse(Create);
        const projectName = args.projectName;
        const fileToCompile = [
            {
                sourceFile: 'package.json.hbs',
                compiledFile: 'package.json',
                filePath: projectName,
                compilerData: { 'projectName': projectName }
            },
            {
                sourceFile: 'src/index.html.hbs',
                compiledFile: 'src/index.html',
                filePath: projectName,
                compilerData: { 'projectName': projectName }
            },
            {
                sourceFile: 'src/components/App/App.tsx.hbs',
                compiledFile: 'src/components/App/App.tsx',
                filePath: projectName,
                compilerData: { 'projectName': projectName }
            }
        ];
        const hiddenFiles = [
            {
                source: 'gitignore',
                destination: '.gitignore'
            },
            {
                source: 'babelrc',
                destination: '.babelrc'
            }
        ];
        if (projectName) {
            // create folder
            Utils_1.Utils.CreateFolder(projectName);
            // copy file
            Utils_1.Utils.CopyTemplate(projectName, 'create');
            // move hidden file
            hiddenFiles.map(hiddenFile => Utils_1.Utils.MoveFile(projectName, hiddenFile.source, hiddenFile.destination));
            // compile template
            Utils_1.Utils.CompileTemplate(fileToCompile);
            // install dependency
            Utils_1.Utils.ExecNpmCommand(projectName, 'install');
        }
        else {
            await Create.run(['--help']);
        }
    }
}
exports.default = Create;
Create.description = 'create an empty starter project';
Create.examples = [
    `$ reactscript-cli create new-app`,
];
Create.flags = {
    help: command_1.flags.help({ char: 'h' }),
};
Create.args = [
    {
        name: 'projectName'
    }
];
